@@ -15,9 +15,11 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+   USA.  */
 
-#include "silo.h"
+#include <silo.h>
+#include <stringops.h>
 
 static int net = 0;
 static int floppy = 0;
@@ -175,7 +177,7 @@ int read (char *buff, int size, unsigned long long offset)
     	    return (*romvec->pv_v0devops.v0_rdnetdev) (fd, size, buff);
 	else {
 	    char buffer[512];
-	    int i = 0, j, k, rc, ret = 0;
+	    int i = 0, j, k, rc = 0, ret = 0;
 
 	    if (offset & 0x1ff) {
 	        if (size > 512 - (offset & 0x1ff))
@@ -233,7 +235,7 @@ int read (char *buff, int size, unsigned long long offset)
 	    return ret;
 	}
     } else {
-	int rc;
+	int rc = 0;
 
         if (flash) {
             unsigned int word;
@@ -288,7 +290,7 @@ int read (char *buff, int size, unsigned long long offset)
 		    if (((romvec->pv_printrev >> 16) < 2 || 
 		         ((romvec->pv_printrev >> 16) == 2 && (romvec->pv_printrev && 0xffff) < 6)) 
 		        && offset >= 0x40000000) {
-		    	printf ("Buggy old PROMs don't allow reading past 1GB from start of the disk. Send complains to SMCC\n");
+		    	printf ("Buggy old PROMs don't allow reading past 1GB from start of the disk. Send complaints to SMCC\n");
 	    		return -1;
 	    	    }
 	    }
@@ -319,7 +321,8 @@ int read (char *buff, int size, unsigned long long offset)
 		    reopen();
 		    while (size) {
 			if (size < 32768) j = size; else j = 32768;
-			if (read (buff, j, offset) != j) return -1;
+			if (read (buff, j, offset) != j)
+			    return -1;
 			size -= j;
 			offset += j;
 			buff += j;
