@@ -16,11 +16,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+   USA.  */
 
-#include "silo.h"
+#include <silo.h>
 #include <asm/idprom.h>
 #include <asm/machines.h>
+#include <stringops.h>
 
 void fatal (const char *msg)
 {
@@ -467,7 +469,7 @@ void set_prollargs (char *params, unsigned int kbase, int ksize)
         return;
     }
     /* PROLL's base address is floating often. Mask the linking address off. */
-    p = v[3] & (0x40000-1);
+    p = (struct silo_to_proll *)(v[3] & (0x40000-1));
     if (p->magic[0] != 'L' || p->magic[1] != 'R') {
 	printf ("Bad magic in PROLL parameter");
 	return;
